@@ -11,6 +11,7 @@
 ##' @param testNonNormal A function used to perform the nonparametric tests. The default is \code{svyranktest}.
 ##' @param argsNonNormal A named list of arguments passed to the function specified in \code{testNonNormal}.
 ##' @param smd If TRUE, as in the default and there are more than two groups, standardized mean differences for all pairwise comparisons are calculated.
+##' @param addOverall (optional, only used if strata are supplied) Adds an overall column to the table. Smd and p-value calculations are performed using only the stratifed clolumns.
 ##' @return An object of class \code{svyContTable}.
 ##' @author Kazuki Yoshida
 ##' @seealso
@@ -29,7 +30,8 @@ function(vars,                                  # character vector of variable n
          argsNormal    = list(method = "Wald"), # arguments passed to testNormal
          testNonNormal = svyTestNonNormal,      # test for nonnormally distributed variables
          argsNonNormal = NULL,                  # arguments passed to testNonNormal
-         smd           = TRUE                   # whether to include standardize mean differences
+         smd           = TRUE,                  # whether to include standardize mean differences
+         addOverall    = FALSE
          ) {
 
 ### Data check
@@ -148,6 +150,13 @@ function(vars,                                  # character vector of variable n
         smds <- FormatLstSmds(smds, nStrata = length(result))
     }
 
+    if (isTRUE(addOverall) & is.list(strata)) {
+        ## Get Overall Table
+        result <- c(ModuleCreateOverallColumn(match.call()), result)
+        ## Fix attributes
+        attributes(result)$names <- c(attributes(result)$names[1], strataVarLevels)
+        attributes(result) <- c(attributes(result), list(strataVarName = strataVarName))
+    }
 
     ## Return object
     ## Give an S3 class
